summaryrefslogtreecommitdiff
path: root/plugins
diff options
context:
space:
mode:
authorRobert Pösel <robyer@seznam.cz>2012-09-10 13:08:12 +0000
committerRobert Pösel <robyer@seznam.cz>2012-09-10 13:08:12 +0000
commit16ea608b527932e6c10add8258fca3785b4e7790 (patch)
tree48715a33cb1d041d7a19322003e755917f8c038e /plugins
parent1c2db19fd58e4f3abc32a3b8c0d3a0b189ca4d00 (diff)
MenuItemEx: Reset logoff timestamp for online contacts
git-svn-id: http://svn.miranda-ng.org/main/trunk@1561 1316c22d-e87f-b044-9b9b-93d7a3e3ba9c
Diffstat (limited to 'plugins')
-rw-r--r--plugins/MenuItemEx/src/main.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/MenuItemEx/src/main.cpp b/plugins/MenuItemEx/src/main.cpp
index 547cfbf290..b3b06e867d 100644
--- a/plugins/MenuItemEx/src/main.cpp
+++ b/plugins/MenuItemEx/src/main.cpp
@@ -1182,12 +1182,12 @@ static int ContactSettingChanged( WPARAM wParam, LPARAM lParam )
if (oldStatus == ID_STATUS_OFFLINE)
{
- // set online timestamp for this contact, only when not set already
+ // set logon timestamp for this contact, only when not set already
if (!DBGetContactSettingDword(hContact, lpzProto, "LogonTS", FALSE))
DBWriteContactSettingDword(hContact, lpzProto, "LogonTS", ( DWORD )time(NULL));
- // TODO: don't reset logoff timestamp?
- // DBDeleteContactSetting(hContact, lpzProto, "LogoffTS");
+ // reset logoff timestamp
+ DBDeleteContactSetting(hContact, lpzProto, "LogoffTS");
// TESTING: updating user's details
if (DBGetContactSettingDword(NULL, VISPLG, "flags", vf_default) & VF_REFRESH)
@@ -1199,7 +1199,7 @@ static int ContactSettingChanged( WPARAM wParam, LPARAM lParam )
}
if (newStatus == ID_STATUS_OFFLINE)
{
// set offline timestamp for this contact
DBWriteContactSettingDword(hContact, lpzProto, "LogoffTS", ( DWORD )time(NULL));
// reset logon timestamp
DBDeleteContactSetting(hContact, lpzProto, "LogonTS");
@@ -1199,7 +1199,7 @@ static int ContactSettingChanged( WPARAM wParam, LPARAM lParam )
if (newStatus == ID_STATUS_OFFLINE)
{
- // set offline timestamp for this contact
+ // set logoff timestamp for this contact
DBWriteContactSettingDword(hContact, lpzProto, "LogoffTS", ( DWORD )time(NULL));
// reset logon timestamp